@@ -986,6 +986,8 @@ class ModelCatalog:
         project_id=None,
         display_name=None,
         description=None,
+        freeform_tags=None,
+        defined_tags=None
     ):
         """
         Uploads the model artifact to cloud storage.
@@ -1003,6 +1005,10 @@ class ModelCatalog:
             The name of model.
         description: str, optional
             The description of model.
+        freeform_tags : dict(str, str), optional
+            Freeform tags for the model, by default None
+        defined_tags : dict(str, dict(str, object)), optional
+            Defined tags for the model, by default None
 
         Returns
         -------
@@ -1015,7 +1021,6 @@ class ModelCatalog:
             if project_id is None:
                 raise ValueError("project_id needs to be specified.")
             schema_file = os.path.join(model_artifact.artifact_dir, "schema.json")
-            freeform_tags = {}
             if os.path.exists(schema_file):
                 with open(schema_file, "r") as schema:
                     metadata = json.load(schema)
@@ -1038,8 +1043,11 @@ class ModelCatalog:
                 output_schema=model_artifact.schema_output.to_json()
                 if model_artifact.schema_output is not None
                 else '{"schema": []}',
+                freeform_tags=freeform_tags,
+                defined_tags=defined_tags
+
             )
-            # freeform_tags=freeform+tags)
+
             model = self.ds_client.create_model(create_model_details)
             self._upload_model_artifact(model.data.id, model_artifact, progress)
             if provenance_metadata is not None:
