@@ -10,9 +10,6 @@ import oci
 from oci.config import from_file
 from oci.data_science import DataScienceClient
 from oci.data_science.models import (
-    CreateModelDetails,
-    ModelSummary,
-    Model,
     NotebookSessionSummary,
     UpdateNotebookSessionDetails,
     CreateNotebookSessionDetails,
