@@ -48,8 +48,8 @@ from ads.common.model_metadata import (
     ModelTaxonomyMetadata,
     MetadataTaxonomyKeys,
     UseCaseType,
-    InvalidObjectStoragePath,
 )
+from ads.common.utils import InvalidObjectStoragePath
 from ads.config import (
     NB_SESSION_OCID,
     JOB_RUN_OCID,
@@ -770,7 +770,7 @@ class ModelArtifact(Introspectable):
                 runtime_prep_info = yaml.load(mfile, Loader=yaml.FullLoader)
                 # runtime_info['pack-info'] = deployment_pack_info
         else:
-            runtime_prep_info = "{}"
+            runtime_prep_info = {}
         ns = self.__fetch_runtime_schema__()
         runtime_info = ns.ModelArtifactSchema().from_json(json.dumps(runtime_prep_info))
 
