@@ -108,7 +108,7 @@ def prepare_generic_model(
     >>> from ads.common.model_export_util import prepare_generic_model
     >>> import yaml
     >>>
-    >>> ads.set_auth('api_keys', profile='DEFAULT')
+    >>> ads.set_auth('api_key', profile='DEFAULT')
     >>> model_artifact_location = os.path.expanduser('~/myusecase/model/')
     >>> inference_conda_env="oci://my-bucket@namespace/conda_environments/cpu/Data Exploration and Manipulation for CPU Python 3.7/2.0/dataexpl_p37_cpu_v2"
     >>> inference_python_version = "3.7"
