@@ -1,3 +1,10 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*--
+
+# Copyright (c) 2021 Oracle and/or its affiliates.
+# Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
+
+
 import json
 import logging
 import os
@@ -31,12 +38,6 @@ METADATA_DESCRIPTION_LENGTH_LIMIT = 255
 _METADATA_EMPTY_VALUE = "NA"
 
 
-class InvalidObjectStoragePath(Exception):
-    """Invalid Object Storage Path."""
-
-    pass
-
-
 class MetadataSizeTooLarge(ValueError):
     def __init__(self, size: int):
         super().__init__(
@@ -279,9 +280,9 @@ class ModelMetadataItem(ABC):
         {'log_requests': False,
             'additional_user_agent': '',
             'pass_phrase': None,
-            'user': 'ocid1.user.oc1..aaaaaaaab3geixlk***********************',
+            'user': '<user-id>',
             'fingerprint': '05:15:2b:b1:46:8a:32:ec:e2:69:5b:32:01:**:**:**)',
-            'tenancy': 'ocid1.tenancy.oc1..aaaaaaaag*************************',
+            'tenancy': '<tenency-id>',
             'region': 'us-ashburn-1',
             'key_file': '/home/datascience/.oci/oci_api_key.pem'}
         >>> metadata_item.to_json_file(file_path = 'oci://bucket_name@namespace/folder_name/file.json', storage_options=storage_options)
@@ -900,9 +901,9 @@ class ModelMetadata(ABC):
         {'log_requests': False,
             'additional_user_agent': '',
             'pass_phrase': None,
-            'user': 'ocid1.user.oc1..aaaaaaaab3geixlk***********************',
+            'user': '<user-id>',
             'fingerprint': '05:15:2b:b1:46:8a:32:ec:e2:69:5b:32:01:**:**:**)',
-            'tenancy': 'ocid1.tenancy.oc1..aaaaaaaag*************************',
+            'tenancy': '<tenancy-id>',
             'region': 'us-ashburn-1',
             'key_file': '/home/datascience/.oci/oci_api_key.pem'}
         >>> metadata.to_json_file(file_path = 'oci://bucket_name@namespace/folder_name/metadata_taxonomy.json', storage_options=storage_options)
