@@ -5,7 +5,7 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 """Contains class wrapping OCI resource search service
 """
-import oci
+import oci.resource_search
 from ads.common.oci_mixin import OCIClientMixin
 
 
