@@ -936,6 +936,12 @@ def to_dataframe(
         )
 
 
+class InvalidObjectStoragePath(Exception):
+    """Invalid Object Storage Path."""
+
+    pass
+
+
 def _log_missing_module(module, package):
     """
     Log message for missing module
@@ -953,3 +959,10 @@ def _log_plot_high_cardinality_warning(s, length):
     logger.warning(
         f"There are too many distinct values for {s} ({length:,}) to plot. Only the top {MAX_DISPLAY_VALUES}, by cardinality, will be used."
     )
+
+
+def _snake_to_camel(name, capitalized_first_token=False):
+    tokens = name.split("_")
+    return (tokens[0].capitalize() if capitalized_first_token else tokens[0]) + "".join(
+        x.capitalize() if not x.isupper() else x for x in tokens[1:]
+    )
