@@ -15,10 +15,14 @@ NB_SESSION_OCID = os.environ.get("NB_SESSION_OCID") or None
 USER_OCID = os.environ.get("USER_OCID") or None
 
 # resource principal env vars
-OCI_RESOURCE_PRINCIPAL_RPT_ENDPOINT = os.environ.get("OCI_RESOURCE_PRINCIPAL_RPT_ENDPOINT")
+OCI_RESOURCE_PRINCIPAL_RPT_ENDPOINT = os.environ.get(
+    "OCI_RESOURCE_PRINCIPAL_RPT_ENDPOINT"
+)
 OCI_RESOURCE_PRINCIPAL_VERSION = os.environ.get("OCI_RESOURCE_PRINCIPAL_VERSION")
 OCI_RESOURCE_PRINCIPAL_RPT_PATH = os.environ.get("OCI_RESOURCE_PRINCIPAL_RPT_PATH")
 OCI_RESOURCE_PRINCIPAL_RPT_ID = os.environ.get("OCI_RESOURCE_PRINCIPAL_RPT_ID")
 
 TENANCY_OCID = os.environ.get("TENANCY_OCID")
-OCI_REGION_METADATA = os.environ.get("OCI_REGION_METADATA")
\ No newline at end of file
+OCI_REGION_METADATA = os.environ.get("OCI_REGION_METADATA")
+
+JOB_RUN_OCID = os.environ.get("JOB_RUN_OCID") or None
