@@ -8,6 +8,7 @@ from ads.dataset.dataset_with_target import ADSDatasetWithTarget
 
 
 class RegressionDataset(ADSDatasetWithTarget):
-
     def __init__(self, ddf, sampled_df, target, target_type, shape, **kwargs):
-        ADSDatasetWithTarget.__init__(self, ddf, sampled_df, target, target_type, shape, **kwargs)
+        ADSDatasetWithTarget.__init__(
+            self, ddf, sampled_df, target, target_type, shape, **kwargs
+        )
