@@ -14,7 +14,10 @@ from ads.explanations.base_explainer import GlobalExplainer
 from ads.explanations.mlx_interface import check_tabular_or_text
 from ads.explanations.mlx_interface import init_lime_explainer
 from ads.explanations.mlx_interface import init_permutation_importance_explainer
-from ads.explanations.mlx_interface import init_partial_dependence_explainer, init_ale_explainer
+from ads.explanations.mlx_interface import (
+    init_partial_dependence_explainer,
+    init_ale_explainer,
+)
 
 
 class MLXGlobalExplainer(GlobalExplainer):
@@ -37,17 +40,16 @@ class MLXGlobalExplainer(GlobalExplainer):
         - Regression.
 
     """
+
     def __init__(self):
         super(GlobalExplainer, self).__init__()
         self.explainer = None
         self.pdp_explainer = None
         self.ale_explainer = None
 
-    def compute_feature_importance(self,
-                                   n_iter=20,
-                                   sampling=None,
-                                   balance=False,
-                                   scoring_metric=None):
+    def compute_feature_importance(
+        self, n_iter=20, sampling=None, balance=False, scoring_metric=None
+    ):
         """
         Generates a global explanation to help understand the general behavior
         of the model. This explainer identifies which features are most important
@@ -99,7 +101,7 @@ class MLXGlobalExplainer(GlobalExplainer):
 
                 Multi-class Classification:
                     `f1_weighted`, `f1_micro`, `f1_macro`, `recall_weighted`, `recall_micro`, `recall_macro`,
-                    `accuracy`, `balanced_accuracy`, `roc_auc`, `precision_weighted`, `precision_macro`, 
+                    `accuracy`, `balanced_accuracy`, `roc_auc`, `precision_weighted`, `precision_macro`,
                     `precision_micro`
                 Binary Classification:
                     Same as multi-class classification.
@@ -116,38 +118,78 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
         if self.explainer is None:
             self._init_feature_importance()
-        if self.explainer.config.type == 'text':
+        if self.explainer.config.type == "text":
             labels = list(range(len(self.class_names)))
             # The requirement to downsample the text datasets should be fixed at somepoint
             if sampling is None:
-                sampling = {'technique': 'random', 'n_samples': 40}
-            explanation = self.explainer.explain_aggregate_local(self.X_test, sampling=sampling, labels=labels)
+                sampling = {"technique": "random", "n_samples": 40}
+            explanation = self.explainer.explain_aggregate_local(
+                self.X_test, sampling=sampling, labels=labels
+            )
         else:
             if self.mode_ == "regression":
-                allowed_metrics = ["r2", "neg_mean_squared_error", "neg_root_mean_squared_error", "neg_mean_absolute_error",
-                    "neg_median_absolute_error", "neg_mean_absolute_percentage_error",
-                    "neg_symmetric_mean_absolute_percentage_error"]
+                allowed_metrics = [
+                    "r2",
+                    "neg_mean_squared_error",
+                    "neg_root_mean_squared_error",
+                    "neg_mean_absolute_error",
+                    "neg_median_absolute_error",
+                    "neg_mean_absolute_percentage_error",
+                    "neg_symmetric_mean_absolute_percentage_error",
+                ]
             elif self.mode_ == "classification" and len(self.class_names) == 2:
-                #Binary classification
-                allowed_metrics = ["f1_weighted", "f1_micro", "f1_macro", "recall_weighted", "recall_micro", "recall_macro",
-                    "accuracy", "balanced_accuracy", "roc_auc", "precision_weighted", "precision_macro", "precision_micro"]
+                # Binary classification
+                allowed_metrics = [
+                    "f1_weighted",
+                    "f1_micro",
+                    "f1_macro",
+                    "recall_weighted",
+                    "recall_micro",
+                    "recall_macro",
+                    "accuracy",
+                    "balanced_accuracy",
+                    "roc_auc",
+                    "precision_weighted",
+                    "precision_macro",
+                    "precision_micro",
+                ]
             else:
-                #Multiclass classification
-                allowed_metrics = ["f1_weighted", "f1_micro", "f1_macro", "recall_weighted", "recall_micro", "recall_macro",
-                    "accuracy", "balanced_accuracy", "roc_auc", "precision_weighted", "precision_macro", "precision_micro"]
+                # Multiclass classification
+                allowed_metrics = [
+                    "f1_weighted",
+                    "f1_micro",
+                    "f1_macro",
+                    "recall_weighted",
+                    "recall_micro",
+                    "recall_macro",
+                    "accuracy",
+                    "balanced_accuracy",
+                    "roc_auc",
+                    "precision_weighted",
+                    "precision_macro",
+                    "precision_micro",
+                ]
             if scoring_metric not in allowed_metrics and scoring_metric is not None:
-                raise Exception('Scoring Metric not supported for this type of problem: {}, for problem type {}, the availble supported metrics are {}'.format(scoring_metric, self.mode_, allowed_metrics))
+                raise Exception(
+                    "Scoring Metric not supported for this type of problem: {}, for problem type {}, the availble supported metrics are {}".format(
+                        scoring_metric, self.mode_, allowed_metrics
+                    )
+                )
             if balance and sampling is None:
-                sampling = {'technique': 'random'}
-            explanation = self.explainer.compute(self.X_test, self.y_test, n_iter=n_iter, sampling=sampling,
-                                                 balance=balance, scoring_metric=scoring_metric)
+                sampling = {"technique": "random"}
+            explanation = self.explainer.compute(
+                self.X_test,
+                self.y_test,
+                n_iter=n_iter,
+                sampling=sampling,
+                balance=balance,
+                scoring_metric=scoring_metric,
+            )
         return FeatureImportance(explanation, self.class_names, self.explainer.config)
-    
-    def compute_partial_dependence(self,
-                                   features,
-                                   partial_range=(0.00, 1.0),
-                                   num_samples=30,
-                                   sampling=None):
+
+    def compute_partial_dependence(
+        self, features, partial_range=(0.00, 1.0), num_samples=30, sampling=None
+    ):
         """
         Generates a global partial dependence plot (PDP) and individual conditional
         expectation (ICE) plots to help understand the relationship between feature
@@ -162,7 +204,7 @@ class MLXGlobalExplainer(GlobalExplainer):
             List of feature names or feature indices to explain.
 
         partial_range : tuple, optional
-            2-tuple with the minimum and maximum percentile values to consider for the PDP from 
+            2-tuple with the minimum and maximum percentile values to consider for the PDP from
             the feature's train distribution. Must be between 0.0 and 1.0.
             Defaults to `partial_range = (0.05, 0.95)`.
 
@@ -222,26 +264,45 @@ class MLXGlobalExplainer(GlobalExplainer):
             if hasattr(self.est, "selected_features_"):
                 selected_features = self.est.selected_features_
                 boolean_list = tuple(x in selected_features for x in feature_ids)
-                filtered_list = [i for indx, i in enumerate(feature_ids) if boolean_list[indx] == False]
+                filtered_list = [
+                    i
+                    for indx, i in enumerate(feature_ids)
+                    if boolean_list[indx] == False
+                ]
                 if not all(boolean_list):
-                    print("Feature:", self.X_train.columns.values[filtered_list], "is not selected by the model.")
+                    print(
+                        "Feature:",
+                        self.X_train.columns.values[filtered_list],
+                        "is not selected by the model.",
+                    )
                     return
 
             if len(feature_ids) > 2:
                 raise ValueError("Maximum number of partial dependency features is 2.")
 
-            return MLXPartialDependencies(pdp=self.pdp_explainer.compute(
-                data=self.X_train, partial_ids=feature_ids, partial_range=partial_range,
-                num_samples=num_samples, sampling=sampling), pdp_exp=self.pdp_explainer)
+            return MLXPartialDependencies(
+                pdp=self.pdp_explainer.compute(
+                    data=self.X_train,
+                    partial_ids=feature_ids,
+                    partial_range=partial_range,
+                    num_samples=num_samples,
+                    sampling=sampling,
+                ),
+                pdp_exp=self.pdp_explainer,
+            )
         else:
-            raise ValueError("Partial Dependence Plot is not supported for text classification dataset.")
+            raise ValueError(
+                "Partial Dependence Plot is not supported for text classification dataset."
+            )
 
-    def compute_accumulated_local_effects(self,
-                                          feature,
-                                          partial_range=(0.00, 1.0),
-                                          num_samples=30,
-                                          sampling=None,
-                                          corr_threshold=0.7):
+    def compute_accumulated_local_effects(
+        self,
+        feature,
+        partial_range=(0.00, 1.0),
+        num_samples=30,
+        sampling=None,
+        corr_threshold=0.7,
+    ):
         """
         Generates the accumulated local effects plots to help understand the relationship between feature
         values and the model target.
@@ -315,20 +376,39 @@ class MLXGlobalExplainer(GlobalExplainer):
             if hasattr(self.est, "selected_features_"):
                 selected_features = self.est.selected_features_
                 boolean_list = tuple(x in selected_features for x in feature_ids)
-                filtered_list = [i for indx, i in enumerate(feature_ids) if boolean_list[indx]==False]
+                filtered_list = [
+                    i
+                    for indx, i in enumerate(feature_ids)
+                    if boolean_list[indx] == False
+                ]
                 if not all(boolean_list):
-                    print("Feature:", self.X_train.columns.values[filtered_list], "is not selected by the model.")
+                    print(
+                        "Feature:",
+                        self.X_train.columns.values[filtered_list],
+                        "is not selected by the model.",
+                    )
                     return
 
             if len(feature_ids) > 1:
-                raise ValueError("Maximum number of Accumulated Local Effects features is 1.")
+                raise ValueError(
+                    "Maximum number of Accumulated Local Effects features is 1."
+                )
 
-            return MLXAccumulatedLocalEffects(ale=self.ale_explainer.compute(
-                data=self.X_train, partial_ids=feature_ids, partial_range=partial_range,
-                num_samples=num_samples, sampling=sampling, corr_threshold=corr_threshold),
-                ale_exp=self.ale_explainer)
+            return MLXAccumulatedLocalEffects(
+                ale=self.ale_explainer.compute(
+                    data=self.X_train,
+                    partial_ids=feature_ids,
+                    partial_range=partial_range,
+                    num_samples=num_samples,
+                    sampling=sampling,
+                    corr_threshold=corr_threshold,
+                ),
+                ale_exp=self.ale_explainer,
+            )
         else:
-            raise ValueError("Accumulated Local Effects Plot is not supported for text classification dataset.")
+            raise ValueError(
+                "Accumulated Local Effects Plot is not supported for text classification dataset."
+            )
 
     def show_in_notebook(self):  # pragma: no cover
         """
@@ -341,11 +421,11 @@ class MLXGlobalExplainer(GlobalExplainer):
             plot1 = explainer_holder.show_in_notebook()
             bar.update("calculating partial dependence plot")
             pdp_plot_feature_name = explainer_holder.explanation
-            #pdp_plot_feature_name = explainer_holder.explanation.get_global_explanation().index[0]
+            # pdp_plot_feature_name = explainer_holder.explanation.get_global_explanation().index[0]
             pdp_plot = self.compute_partial_dependence([pdp_plot_feature_name])
-            #plot2 = pdp_plot.show_in_notebook()
+            # plot2 = pdp_plot.show_in_notebook()
         display(HTML(plot1.data))
-        #display(HTML(plot1.data + plot2.data))
+        # display(HTML(plot1.data + plot2.data))
 
     def configure_feature_importance(self, **kwargs):
         """
@@ -379,20 +459,35 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
 
         if check_tabular_or_text(self.est, self.X_train) == "tabular":
-            avail_args = ['client', 'random_state']
+            avail_args = ["client", "random_state"]
         else:
-            avail_args = ['client', 'random_state', 'surrogate_model', 'num_samples',
-                          'exp_sorting', 'scale_weight', 'batch_size']
+            avail_args = [
+                "client",
+                "random_state",
+                "surrogate_model",
+                "num_samples",
+                "exp_sorting",
+                "scale_weight",
+                "batch_size",
+            ]
 
         for k, _ in kwargs.items():
             if k not in avail_args:
-                raise ValueError('Unexpected argument for the feature importance explainer: {}'.format(k))
+                raise ValueError(
+                    "Unexpected argument for the feature importance explainer: {}".format(
+                        k
+                    )
+                )
 
-        if kwargs.get('client', None) is not None:
-            raise ValueError('Invalid client provided. Currently only supports disabling parallelization '
-                             'by setting client=None')
-        if kwargs.get('surrogate_model', None) not in ['linear', 'decision_tree', None]:
-            raise ValueError('Invalid surrogate_model provided. Currently only supports linear or decision_tree')
+        if kwargs.get("client", None) is not None:
+            raise ValueError(
+                "Invalid client provided. Currently only supports disabling parallelization "
+                "by setting client=None"
+            )
+        if kwargs.get("surrogate_model", None) not in ["linear", "decision_tree", None]:
+            raise ValueError(
+                "Invalid surrogate_model provided. Currently only supports linear or decision_tree"
+            )
 
         self._init_feature_importance(**kwargs)
         return self
@@ -417,11 +512,17 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
 
         for k, _ in kwargs.items():
-            if k not in ['client']:
-                raise ValueError('Unexpected argument for the partial dependence explainer: {}'.format(k))
-        if kwargs.get('client', None) is not None:
-            raise ValueError('Invalid client provided. Currently only supports disabling parallelization '
-                             'by setting client=None')
+            if k not in ["client"]:
+                raise ValueError(
+                    "Unexpected argument for the partial dependence explainer: {}".format(
+                        k
+                    )
+                )
+        if kwargs.get("client", None) is not None:
+            raise ValueError(
+                "Invalid client provided. Currently only supports disabling parallelization "
+                "by setting client=None"
+            )
         self._init_partial_dependence(**kwargs)
         return self
 
@@ -445,11 +546,17 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
 
         for k, _ in kwargs.items():
-            if k not in ['client']:
-                raise ValueError('Unexpected argument for the accumulated local effects explainer: {}'.format(k))
-        if kwargs.get('client', None) is not None:
-            raise ValueError('Invalid client provided. Currently only supports disabling parallelization '
-                             'by setting client=None')
+            if k not in ["client"]:
+                raise ValueError(
+                    "Unexpected argument for the accumulated local effects explainer: {}".format(
+                        k
+                    )
+                )
+        if kwargs.get("client", None) is not None:
+            raise ValueError(
+                "Invalid client provided. Currently only supports disabling parallelization "
+                "by setting client=None"
+            )
         self._init_accumulated_local_effects(**kwargs)
         return self
 
@@ -461,7 +568,7 @@ class MLXGlobalExplainer(GlobalExplainer):
         ------
         str
             HTML object representing the explainer summary.
-            
+
         """
 
         if self.explainer is None:
@@ -491,13 +598,12 @@ class MLXGlobalExplainer(GlobalExplainer):
         str
             HTML object representing the explainer summary.
         """
-        
+
         if self.ale_explainer is None:
             self._init_accumulated_local_effects()
         return self.ale_explainer.show_in_notebook()
 
-    def _init_feature_importance(self,
-                                 **kwargs):
+    def _init_feature_importance(self, **kwargs):
         """
         Internal function to initializes the feature importance explainer. Tabular datasets
         use the feature permutation importance explainer, text datasets use the aggregate local
@@ -511,17 +617,29 @@ class MLXGlobalExplainer(GlobalExplainer):
         if self.mode == "regression":
             self.class_names_ = ["Target"]
         if check_tabular_or_text(self.est, self.X_train) == "tabular":
-            self.explainer = init_permutation_importance_explainer(self.explainer, self.est,
-                                                                   self.X_train, self.y_train,
-                                                                   self.mode, class_names=self.class_names,
-                                                                   use_pre_selected_features=True, **kwargs)
+            self.explainer = init_permutation_importance_explainer(
+                self.explainer,
+                self.est,
+                self.X_train,
+                self.y_train,
+                self.mode,
+                class_names=self.class_names,
+                use_pre_selected_features=True,
+                **kwargs
+            )
         else:
-            self.explainer = init_lime_explainer(self.explainer, self.est, self.X_train, self.y_train,
-                                                 self.mode, class_names=self.class_names,
-                                                 use_pre_selected_features=True, **kwargs)
+            self.explainer = init_lime_explainer(
+                self.explainer,
+                self.est,
+                self.X_train,
+                self.y_train,
+                self.mode,
+                class_names=self.class_names,
+                use_pre_selected_features=True,
+                **kwargs
+            )
 
-    def _init_partial_dependence(self,
-                                 **kwargs):
+    def _init_partial_dependence(self, **kwargs):
         """
         Internal function to initialize the partial dependence explainer.
 
@@ -532,9 +650,15 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
         if self.mode == "regression":
             self.class_names_ = ["Target"]
-        self.pdp_explainer = init_partial_dependence_explainer(self.pdp_explainer, self.est,
-                                                                self.X_train, self.y_train, self.mode,
-                                                                class_names=self.class_names, **kwargs)
+        self.pdp_explainer = init_partial_dependence_explainer(
+            self.pdp_explainer,
+            self.est,
+            self.X_train,
+            self.y_train,
+            self.mode,
+            class_names=self.class_names,
+            **kwargs
+        )
 
     def _init_accumulated_local_effects(self, **kwargs):
         """
@@ -547,35 +671,37 @@ class MLXGlobalExplainer(GlobalExplainer):
         """
         if self.mode == "regression":
             self.class_names_ = ["Target"]
-        self.ale_explainer = init_ale_explainer(self.ale_explainer,
-                                                self.est,
-                                                self.X_train,
-                                                self.y_train,
-                                                self.mode,
-                                                class_names=self.class_names,
-                                                **kwargs)
+        self.ale_explainer = init_ale_explainer(
+            self.ale_explainer,
+            self.est,
+            self.X_train,
+            self.y_train,
+            self.mode,
+            class_names=self.class_names,
+            **kwargs
+        )
 
 
 class MLXFeatureDependenceExplanation(ABC):
 
     __name__ = "MLXFeatureDependenceExplanation"
 
-    def __init__(self,
-                 fd,
-                 fd_exp):
+    def __init__(self, fd, fd_exp):
         self.fd = fd
         self.fd_exp = fd_exp
 
     @abstractmethod
-    def show_in_notebook(self,
-                         labels=None,
-                         cscale='YIGnBu',
-                         show_distribution=True,
-                         discrete_threshold=0.15,
-                         # line_gap=0,  # will add it back after ALE starts handling two features, remember to add the doc string too
-                         show_correlation_warning=True,
-                         centered=False,
-                         show_median=True):  # pragma: no cover
+    def show_in_notebook(
+        self,
+        labels=None,
+        cscale="YIGnBu",
+        show_distribution=True,
+        discrete_threshold=0.15,
+        # line_gap=0,  # will add it back after ALE starts handling two features, remember to add the doc string too
+        show_correlation_warning=True,
+        centered=False,
+        show_median=True,
+    ):  # pragma: no cover
         """
         Visualize PDP/ICE plots in the Notebook.
 
@@ -637,23 +763,24 @@ class MLXPartialDependencies(MLXFeatureDependenceExplanation):
 
     Contains functions to visualize the explanation and extract raw explanation data.
     """
+
     __name__ = "MLXPartialDependencies"
 
-    def __init__(self,
-                 pdp,
-                 pdp_exp):
+    def __init__(self, pdp, pdp_exp):
         super(MLXPartialDependencies, self).__init__(pdp, pdp_exp)
 
-    def show_in_notebook(self,
-                         mode='pdp',
-                         labels=None,
-                         cscale='YIGnBu',
-                         show_distribution=True,
-                         discrete_threshold=0.15,
-                         line_gap=0,
-                         show_correlation_warning=True,
-                         centered=False,
-                         show_median=True):
+    def show_in_notebook(
+        self,
+        mode="pdp",
+        labels=None,
+        cscale="YIGnBu",
+        show_distribution=True,
+        discrete_threshold=0.15,
+        line_gap=0,
+        show_correlation_warning=True,
+        centered=False,
+        show_median=True,
+    ):
         """
         Visualize PDP/ICE plots in the Notebook.
 
@@ -687,10 +814,17 @@ class MLXPartialDependencies(MLXFeatureDependenceExplanation):
         str
             Plotly HTML object containing a line chart, heat map, or violin plot for this feature dependence explanation
         """
-        return self.fd.show_in_notebook(mode=mode, labels=labels, cscale=cscale, show_distribution=show_distribution,
-                                        discrete_threshold=discrete_threshold, line_gap=line_gap,
-                                        show_correlation_warning=show_correlation_warning,
-                                        centered=centered, show_median=show_median)
+        return self.fd.show_in_notebook(
+            mode=mode,
+            labels=labels,
+            cscale=cscale,
+            show_distribution=show_distribution,
+            discrete_threshold=discrete_threshold,
+            line_gap=line_gap,
+            show_correlation_warning=show_correlation_warning,
+            centered=centered,
+            show_median=show_median,
+        )
 
 
 class MLXAccumulatedLocalEffects(MLXFeatureDependenceExplanation):
@@ -700,21 +834,22 @@ class MLXAccumulatedLocalEffects(MLXFeatureDependenceExplanation):
     Contains functions to visualize the explanation in a Notebook and extract the
     raw explanation data.
     """
+
     __name__ = "MLXAccumulatedLocalEffects"
 
-    def __init__(self,
-                 ale,
-                 ale_exp):
+    def __init__(self, ale, ale_exp):
         super(MLXAccumulatedLocalEffects, self).__init__(ale, ale_exp)
 
-    def show_in_notebook(self,
-                         labels=None,
-                         cscale='YIGnBu',
-                         show_distribution=True,
-                         discrete_threshold=0.15,
-                         show_correlation_warning=True,
-                         centered=False,
-                         show_median=True):
+    def show_in_notebook(
+        self,
+        labels=None,
+        cscale="YIGnBu",
+        show_distribution=True,
+        discrete_threshold=0.15,
+        show_correlation_warning=True,
+        centered=False,
+        show_median=True,
+    ):
         """
         Visualize ALE plots in the Notebook.
 
@@ -744,10 +879,17 @@ class MLXAccumulatedLocalEffects(MLXFeatureDependenceExplanation):
         str
             Plotly HTML object containing a line chart, heat map, or violin plot for this feature dependence explanation
         """
-        return self.fd.show_in_notebook(mode='pdp', labels=labels, cscale=cscale, show_distribution=show_distribution,
-                                        discrete_threshold=discrete_threshold, line_gap=0,
-                                        show_correlation_warning=show_correlation_warning,
-                                        centered=centered, show_median=show_median)
+        return self.fd.show_in_notebook(
+            mode="pdp",
+            labels=labels,
+            cscale=cscale,
+            show_distribution=show_distribution,
+            discrete_threshold=discrete_threshold,
+            line_gap=0,
+            show_correlation_warning=show_correlation_warning,
+            centered=centered,
+            show_median=show_median,
+        )
 
 
 class FeatureImportance:
@@ -758,25 +900,25 @@ class FeatureImportance:
     Contains functions to visualize the explanation in a Notebook and extract the
     raw explanation data.
     """
-    def __init__(self,
-                 explanation,
-                 class_names,
-                 type):
+
+    def __init__(self, explanation, class_names, type):
         self.explanation = explanation
         self.class_names = class_names
         self.type = type
         if isinstance(self.class_names, np.ndarray):
             self.class_names = self.class_names.tolist()
 
-    def show_in_notebook(self,
-                         mode=None,
-                         show=None,
-                         labels=None,
-                         cscale='YIGnBu',
-                         colormap=None,
-                         return_wordcloud=False,
-                         n_features=None,
-                         **kwargs):
+    def show_in_notebook(
+        self,
+        mode=None,
+        show=None,
+        labels=None,
+        cscale="YIGnBu",
+        colormap=None,
+        return_wordcloud=False,
+        n_features=None,
+        **kwargs
+    ):
         """
         Generates a visualization for the local explanation. Depending on the type of explanation, different
         visualizations are supported. See the "mode" and "show" parameters below.
@@ -824,7 +966,7 @@ class FeatureImportance:
             to `False`.
         n_features : int, optional
             (tabular only). Allows the user to visualize a subset of the top-N most important features from the explainer.
-            If `n_features` is `None` or greater than the total number of features, all features are shown. If 
+            If `n_features` is `None` or greater than the total number of features, all features are shown. If
             `n_features` is not an `int` or <= 0, an exception is thrown.
         **kwargs : dict
             Keyword arguments for configuring the wordclouds.
@@ -835,23 +977,32 @@ class FeatureImportance:
             HTML string for the visualization or list of generated wordcloud objects if `return_wordcloud=True`,
             two per label (+/-).
         """
-        if self.type.type == 'text':
+        if self.type.type == "text":
             if labels:
-                labels = [self.class_names.index(label) if isinstance(label, str) else label for label in labels]
+                labels = [
+                    self.class_names.index(label) if isinstance(label, str) else label
+                    for label in labels
+                ]
             else:
-                if len(self.class_names) > 1:  # classification
-                    utils.print_user_message("Specify <code>'labels'</code> to plot the local explanation for specific target labels")
                 labels = list(range(len(self.class_names)))
             if len(self.class_names) == 2:
                 return self.explanation.show_in_notebook()
             else:
-                return self.explanation.show_in_notebook(mode=mode if mode else "wordcloud", show=show, labels=labels,
-                                                         cscale=cscale, colormap=colormap, return_wordcloud=return_wordcloud,
-                                                         **kwargs)
+                return self.explanation.show_in_notebook(
+                    mode=mode if mode else "wordcloud",
+                    show=show,
+                    labels=labels,
+                    cscale=cscale,
+                    colormap=colormap,
+                    return_wordcloud=return_wordcloud,
+                    **kwargs
+                )
         else:
             if labels:
                 raise ValueError("label is supported only for text explanation.")
-            return self.explanation.show_in_notebook(n_features=n_features, mode=mode if mode else "bar")
+            return self.explanation.show_in_notebook(
+                n_features=n_features, mode=mode if mode else "bar"
+            )
 
     def get_global_explanation(self):
         """
