@@ -22,8 +22,7 @@ def _reset_index(x):
     return x.reset_index(drop=True)
 
 
-def _get_pre_selected_features(est,
-                               use_pre_selected_features=False):
+def _get_pre_selected_features(est, use_pre_selected_features=False):
     """
     If the ML model internal filters out features (e.g., AutoML),
     provide this information to MLX to skip evaluating these features
@@ -48,8 +47,7 @@ def _get_pre_selected_features(est,
         return None
 
 
-def check_tabular_or_text(est,
-                          X):
+def check_tabular_or_text(est, X):
     """
     Returns "text" if a text dataset, "tabular" otherwise.
 
@@ -68,20 +66,22 @@ def check_tabular_or_text(est,
     return "text" if is_text_data(X) else "tabular"
 
 
-def init_lime_explainer(explainer,
-                        est,
-                        X_train,
-                        y_train,
-                        mode,
-                        class_names=None,
-                        use_pre_selected_features=False,
-                        client=None,
-                        batch_size=16,
-                        surrogate_model='linear',
-                        num_samples=5000,
-                        exp_sorting='absolute',
-                        discretization='decile',
-                        scale_weight=True):
+def init_lime_explainer(
+    explainer,
+    est,
+    X_train,
+    y_train,
+    mode,
+    class_names=None,
+    use_pre_selected_features=False,
+    client=None,
+    batch_size=16,
+    surrogate_model="linear",
+    num_samples=5000,
+    exp_sorting="absolute",
+    discretization="decile",
+    scale_weight=True,
+):
     """
     Initializes a local LIME Explainer. Also supports aggregate local
     explanations, which approximates a global behavior based on multiple local explanations.
@@ -139,28 +139,46 @@ def init_lime_explainer(explainer,
         exp = LimeExplainer()
     else:
         if not isinstance(explainer, LimeExplainer):
-            raise TypeError("Invalid explainer provided to "
-                            "init_lime_explainer: {}".format(type(explainer)))
+            raise TypeError(
+                "Invalid explainer provided to "
+                "init_lime_explainer: {}".format(type(explainer))
+            )
         exp = explainer
     exp_type = check_tabular_or_text(est, X_train)
-    exp.set_config(type=exp_type, mode=mode, discretizer=discretization, client=client, batch_size=batch_size,
-                   scale_weight=scale_weight, surrogate_model=surrogate_model, num_samples=num_samples,
-                   exp_sorting=exp_sorting, kernel_width='dynamic')
+    exp.set_config(
+        type=exp_type,
+        mode=mode,
+        discretizer=discretization,
+        client=client,
+        batch_size=batch_size,
+        scale_weight=scale_weight,
+        surrogate_model=surrogate_model,
+        num_samples=num_samples,
+        exp_sorting=exp_sorting,
+        kernel_width="dynamic",
+    )
     selected_features = _get_pre_selected_features(est, use_pre_selected_features)
-    exp.fit(est, X_train, y=y_train, target_names=class_names,
-            selected_features=selected_features)
+    exp.fit(
+        est,
+        X_train,
+        y=y_train,
+        target_names=class_names,
+        selected_features=selected_features,
+    )
     return exp
 
 
-def init_permutation_importance_explainer(explainer,
-                                          est,
-                                          X_train,
-                                          y_train,
-                                          mode,
-                                          class_names=None,
-                                          use_pre_selected_features=False,
-                                          client=None,
-                                          random_state=42):
+def init_permutation_importance_explainer(
+    explainer,
+    est,
+    X_train,
+    y_train,
+    mode,
+    class_names=None,
+    use_pre_selected_features=False,
+    client=None,
+    random_state=42,
+):
     """
     Initializes a Global Feature Permutation Importance Explainer.
 
@@ -201,25 +219,31 @@ def init_permutation_importance_explainer(explainer,
         exp = PermutationImportance()
     else:
         if not isinstance(explainer, PermutationImportance):
-            raise TypeError("Invalid explainer provided to "
-                            "init_permutation_importance_explainer: {}".format(type(explainer)))
+            raise TypeError(
+                "Invalid explainer provided to "
+                "init_permutation_importance_explainer: {}".format(type(explainer))
+            )
         exp = explainer
-    if check_tabular_or_text(est, X_train) == 'text':
-        raise TypeError("Global feature importance explainers are currently not "
-                        "supported for text datasets.")
+    if check_tabular_or_text(est, X_train) == "text":
+        raise TypeError(
+            "Global feature importance explainers are currently not "
+            "supported for text datasets."
+        )
     exp.set_config(mode=mode, client=client, random_state=random_state)
     selected_features = _get_pre_selected_features(est, use_pre_selected_features)
-    exp.fit(est, X_train, y=y_train, target_names=class_names, selected_features=selected_features)
+    exp.fit(
+        est,
+        X_train,
+        y=y_train,
+        target_names=class_names,
+        selected_features=selected_features,
+    )
     return exp
 
 
-def init_partial_dependence_explainer(explainer,
-                                      est,
-                                      X_train,
-                                      y_train,
-                                      mode,
-                                      class_names=None,
-                                      client=None):
+def init_partial_dependence_explainer(
+    explainer, est, X_train, y_train, mode, class_names=None, client=None
+):
     """
     Initializes a Global feature dependence explainer.
 
@@ -256,24 +280,24 @@ def init_partial_dependence_explainer(explainer,
         exp = FDExplainer()
     else:
         if not isinstance(explainer, FDExplainer):
-            raise TypeError("Invalid explainer provided to "
-                            "init_partial_dependence_explainer: {}".format(type(explainer)))
+            raise TypeError(
+                "Invalid explainer provided to "
+                "init_partial_dependence_explainer: {}".format(type(explainer))
+            )
         exp = explainer
-    if check_tabular_or_text(est, X_train) == 'text':
-        raise TypeError("Global partial dependence explainers are currently not "
-                        "supported for text datasets.")
+    if check_tabular_or_text(est, X_train) == "text":
+        raise TypeError(
+            "Global partial dependence explainers are currently not "
+            "supported for text datasets."
+        )
     exp.set_config(mode=mode, client=client)
     exp.fit(est, X_train, y=y_train, target_names=class_names)
     return exp
 
 
-def init_ale_explainer(explainer,
-                       est,
-                       X_train,
-                       y_train,
-                       mode,
-                       class_names=None,
-                       client=None):
+def init_ale_explainer(
+    explainer, est, X_train, y_train, mode, class_names=None, client=None
+):
     """
     Initializes a Global Accumulated Local Effects(ALE) Explainer.
 
@@ -309,40 +333,55 @@ def init_ale_explainer(explainer,
         exp = AleExplainer()
     else:
         if not isinstance(explainer, AleExplainer):
-            raise TypeError("Invalid explainer provided to "
-                            "init_partial_dependence_explainer: {}".format(type(explainer)))
+            raise TypeError(
+                "Invalid explainer provided to "
+                "init_partial_dependence_explainer: {}".format(type(explainer))
+            )
         exp = explainer
-    if check_tabular_or_text(est, X_train) == 'text':
-        raise TypeError("Global partial dependence explainers are currently not "
-                        "supported for text datasets.")
+    if check_tabular_or_text(est, X_train) == "text":
+        raise TypeError(
+            "Global partial dependence explainers are currently not "
+            "supported for text datasets."
+        )
     exp.set_config(mode=mode, client=client)
     exp.fit(est, X_train, y=y_train, target_names=class_names)
     return exp
 
 
-def init_whatif_explainer(explainer,
-                          est,
-                          X_test,
-                          y_test,
-                          mode,
-                          class_names=None,
-                          train=None,
-                          target_title='target',
-                          random_state=42,
-                          **kwargs):
+def init_whatif_explainer(
+    explainer,
+    est,
+    X_test,
+    y_test,
+    mode,
+    class_names=None,
+    train=None,
+    target_title="target",
+    random_state=42,
+    **kwargs
+):
     if explainer is None:
-        width = kwargs.get('width', 1100)
+        width = kwargs.get("width", 1100)
         exp = WhatIf(mode=mode, random_state=random_state, width=width)
     else:
         if not isinstance(explainer, WhatIf):
-            raise TypeError("Invalid explorer provided to "
-                            "init_explorer: {}".format(type(explainer)))
+            raise TypeError(
+                "Invalid explorer provided to "
+                "init_explorer: {}".format(type(explainer))
+            )
         exp = explainer
     exp_type = check_tabular_or_text(est, X_test)
-    if exp_type == 'text':
-        raise TypeError("WhatIf explainer are currently not "
-                        "supported for text datasets.".format(type(explainer)))
-    exp.fit(model=est, X=X_test, y=y_test, target_names=class_names, train=train, target_title=target_title)
+    if exp_type == "text":
+        raise TypeError(
+            "WhatIf explainer are currently not "
+            "supported for text datasets.".format(type(explainer))
+        )
+    exp.fit(
+        model=est,
+        X=X_test,
+        y=y_test,
+        target_names=class_names,
+        train=train,
+        target_title=target_title,
+    )
     return exp
-
-
