@@ -35,7 +35,7 @@ Examples
     0	          4532640527811543
 """
 
-from typing import Dict, List, Union
+from typing import Any, Dict, List, Union
 
 import numpy as np
 import pandas as pd
@@ -45,12 +45,15 @@ from ads.feature_engineering.accessor.mixin.feature_types_mixin import (
     ADSFeatureTypesMixin,
 )
 from ads.oracledb.mixin.oracle_db import OracleDBAccessMixin
+from ads.data_labeling.mixin.data_labeling import DataLabelingAccessMixin
 from pandas.core.dtypes.common import is_list_like
 from ads.feature_engineering import schema
 
 
 @pd.api.extensions.register_dataframe_accessor("ads")
-class ADSDataFrameAccessor(ADSFeatureTypesMixin, EDAMixin, OracleDBAccessMixin):
+class ADSDataFrameAccessor(
+    ADSFeatureTypesMixin, EDAMixin, OracleDBAccessMixin, DataLabelingAccessMixin
+):
     """ADS accessor for the Pandas DataFrame.
 
     Attributes
@@ -127,6 +130,17 @@ class ADSDataFrameAccessor(ADSFeatureTypesMixin, EDAMixin, OracleDBAccessMixin):
         self._obj = pandas_obj
         super().__init__()
         self.columns = self._obj.columns
+        self._info = None
+
+    def info(self) -> Any:
+        """Gets information about the dataframe.
+
+        Returns
+        -------
+        Any
+            The information about the dataframe.
+        """
+        return self._info
 
     @property
     def _feature_type(self) -> Dict[str, List[FeatureType]]:
