@@ -129,7 +129,7 @@ class FeatureValidator:
         1     +1-202-555-0142
 
     >>> PhoneNumber.validator.registered()
-                        Name                Condition                            Handler
+                   Validator                 Condition                            Handler
         ---------------------------------------------------------------------------------
         0    is_phone_number                        ()             phone_number_validator
         1    is_phone_number          ('country_code')   universal_phone_number_validator
@@ -257,10 +257,10 @@ class FeatureValidator:
         pd.DataFrame
             The list of registerd validators.
         """
-        result_df = pd.DataFrame((), columns=["Name", "Condition", "Handler"])
+        result_df = pd.DataFrame((), columns=["Validator", "Condition", "Handler"])
         for key, feature_validator in self._validators.items():
             feature_validators_df = feature_validator.registered()
-            feature_validators_df.insert(0, "Name", key)
+            feature_validators_df.insert(0, "Validator", key)
             result_df = result_df.append(feature_validators_df)
         result_df.reset_index(drop=True, inplace=True)
         return result_df
