@@ -45,7 +45,7 @@ from optuna import study as study_module  # NOQA
 
 with try_import() as _imports:
     from sklearn.base import BaseEstimator, clone, is_classifier
-    from sklearn.metrics.scorer import check_scoring
+    from sklearn.metrics import check_scoring
     from sklearn.model_selection import BaseCrossValidator  # NOQA
     from sklearn.model_selection import check_cv, cross_validate
     from sklearn.pipeline import Pipeline, make_pipeline
@@ -1126,7 +1126,7 @@ class ADSTuner(BaseEstimator):
         fit_params_res = self._get_fit_params_res(X)
 
         classifier = is_classifier(self.model)
-        cv = check_cv(self.cv, y_res, classifier)
+        cv = check_cv(self.cv, y_res, classifier=classifier)
         self._n_splits = cv.get_n_splits(X_res, y_res, groups=groups_res)
 
         # scoring
