@@ -5,32 +5,31 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 import copy
 import datetime
+import io
 import json
+import logging
 import os
 import time
-from typing import Dict, Optional, List
 import urllib.parse
-import io
+from typing import Dict, List, Optional
 
 import fsspec
 import oci.data_flow
 import ocifs
 import yaml
-from IPython.display import display, HTML
-from oci.data_flow.models import CreateApplicationDetails, CreateRunDetails
-
 from ads.common.auth import default_signer
 from ads.common.oci_client import OCIClientFactory
 from ads.common.oci_mixin import OCIModelMixin
 from ads.config import OCI_REGION_METADATA
-from ads.jobs.builders.infrastructure.base import Infrastructure
-from ads.jobs.builders.infrastructure.utils import (
-    normalize_config,
-    batch_convert_case,
-)
+from ads.jobs.builders.infrastructure.base import Infrastructure, RunInstance
+from ads.jobs.builders.infrastructure.utils import batch_convert_case, normalize_config
 from ads.jobs.builders.runtimes.python_runtime import DataFlowRuntime
+from IPython.display import HTML, display
+from oci.data_flow.models import CreateApplicationDetails, CreateRunDetails
 from tqdm import tqdm
 
+logger = logging.getLogger(__name__)
+
 
 class DataFlowApp(OCIModelMixin, oci.data_flow.models.Application):
     @classmethod
@@ -56,6 +55,7 @@ class DataFlowApp(OCIModelMixin, oci.data_flow.models.Application):
         resp = self.client.create_application(
             self.to_oci_model(CreateApplicationDetails)
         )
+        logger.debug(f"Created a DataFlow Application {resp.data}")
         for k, v in json.loads(repr(resp.data)).items():
             setattr(self, k, v)
         return self
@@ -86,7 +86,7 @@ class DataFlowApp(OCIModelMixin, oci.data_flow.models.Application):
         return yaml.safe_dump(self.to_dict())
 
 
-class DataFlowRun(OCIModelMixin, oci.data_flow.models.Run):
+class DataFlowRun(OCIModelMixin, oci.data_flow.models.Run, RunInstance):
 
     TERMINATED_STATES = [
         oci.data_flow.models.Run.LIFECYCLE_STATE_CANCELED,
@@ -114,6 +114,7 @@ class DataFlowRun(OCIModelMixin, oci.data_flow.models.Run):
             a DataFlowRun instance
         """
         resp = self.client.create_run(self.to_oci_model(CreateRunDetails))
+        logger.debug(f"Created a DataFlow Run {resp.data}")
         for k, v in json.loads(repr(resp.data)).items():
             setattr(self, k, v)
         return self
@@ -166,15 +167,33 @@ class DataFlowRun(OCIModelMixin, oci.data_flow.models.Run):
         """
         current = self.status
         timestamp = datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S")
-        print(f"{timestamp} - {self.status}")
+        logger.info(f"{timestamp} - {self.status}")
         while current not in self.TERMINATED_STATES:
             time.sleep(interval)
             if self.status != current:
                 timestamp = datetime.datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S")
-                print(f"{timestamp} - {self.status}")
+                logger.info(f"{timestamp} - {self.status}")
                 current = self.status
         return self
 
+    def watch(self, interval: int = 3) -> "DataFlowRun":
+        """This is an alias of `wait()` method. It waits for a run to terminate.
+
+        Parameters
+        ----------
+        interval: int, optional
+            interval to wait before probing again
+
+        Returns
+        -------
+        DataFlowRun
+            a DataFlowRun instance
+        """
+        logger.info(
+            "This is an alias of `wait`. Logs are available after run completes."
+        )
+        return self.wait(interval=interval)
+
     def __repr__(self) -> str:
         """Displays the object as YAML."""
         return self.to_yaml()
@@ -223,36 +242,63 @@ class DataFlowRun(OCIModelMixin, oci.data_flow.models.Run):
         )
 
 
+class _Log:
+    def __init__(self, run_id, src_type, output_type):
+        self.run_id = run_id
+        self.src_type = src_type
+        self.output_type = output_type
+        self._cache = None
+
+    @property
+    def client(self):
+        return OCIClientFactory(**default_signer()).dataflow
+
+    def _get_logs(self, n=None, reverse=False):
+        if not self._cache:
+            logs = self.client.list_run_logs(self.run_id).data
+            lines = []
+            for log in logs:
+                if log.type == self.output_type and self.src_type == log.source:
+                    lines.extend(
+                        self.client.get_run_log(self.run_id, log.name)
+                        .data.text.lstrip("\x00")
+                        .rstrip("\n")
+                        .splitlines()
+                    )
+            self._cache = lines
+        if n and reverse:
+            return "\n".join(self._cache[-n:])
+        elif n and not reverse:
+            return "\n".join(self._cache[:n])
+        else:
+            return "\n".join(self._cache)
+
+    def __repr__(self):
+        return self._get_logs()
+
+    def head(self, n=None):
+        return self._get_logs(n=n)
+
+    def tail(self, n=None):
+        return self._get_logs(n=n, reverse=True)
+
+    def download(self, path):
+        with open(path, mode="w") as f:
+            f.write(self._get_logs())
+
+
 class _DataFlowLog:
     def __init__(self, run_id, src_type):
         self.run_id = run_id
         self.src_type = src_type
 
-    @property
-    def client(self):
-        return OCIClientFactory(**default_signer()).dataflow
-
     @property
     def stdout(self):
-        return self._get_logs("STDOUT")
+        return _Log(self.run_id, self.src_type, "STDOUT")
 
     @property
     def stderr(self):
-        return self._get_logs("STDERR")
-
-    def _get_logs(self, out_type):
-        logs = self.client.list_run_logs(self.run_id).data
-        out = ""
-        for log in logs:
-            if log.type == out_type and self.src_type == log.source:
-                out += (
-                    self.client.get_run_log(self.run_id, log.name)
-                    .data.text.lstrip("\x00")
-                    .rstrip("\n")
-                )
-                out += "\n"
-        out = out.rstrip("\n")
-        return out
+        return _Log(self.run_id, self.src_type, "STDERR")
 
 
 class DataFlowLogs:
@@ -314,15 +360,19 @@ class DataFlow(Infrastructure):
                 nb_config = nb_session.notebook_session_configuration_details
                 if nb_config.shape in allowed_shapes:
                     defaults["driver_shape"] = nb_config.shape
+                    logger.debug(f"Set driver shape to {nb_config.shape}")
                     defaults["executor_shape"] = nb_config.shape
+                    logger.debug(f"Set executor shape to {nb_config.shape}")
+
             except Exception as e:
-                print(
+                logger.warning(
                     f"Error fetching details about Notebook session: {os.environ['NB_SESSION_OCID']}. {e}"
                 )
 
         defaults["language"] = "PYTHON"
         defaults["spark_version"] = "2.4.4"
         defaults["num_executors"] = 1
+        logger.debug("Set spark version to be 2.4.4.")
         return defaults
 
     @property
@@ -585,6 +635,7 @@ class DataFlow(Infrastructure):
                 "Compartment id is required. Please specify compartment id via 'with_compartment_id()'."
             )
         payload.pop("id", None)
+        logger.debug(f"Creating a DataFlow Application with payload {payload}")
         self.df_app = DataFlowApp(**payload).create()
         self.with_id(self.df_app.id)
         return self
@@ -600,6 +651,7 @@ class DataFlow(Infrastructure):
             dst_path = os.path.join(bucket, os.path.basename(local_path))
         else:
             dst_path = f"oci://{bucket}@{namespace}/{os.path.basename(local_path)}"
+        logger.debug(f"Uploading {local_path} to {dst_path}")
         with fsspec.open(dst_path, mode="wb", **signer) as fto:
             file_system_clz = fsspec.get_filesystem_class(
                 urllib.parse.urlparse(local_path).scheme or "file"
@@ -665,6 +717,7 @@ class DataFlow(Infrastructure):
         payload["arguments"] = args if args and len(args) > 0 else None
         payload["freeform_tags"] = freeform_tags
         payload.pop("spark_version", None)
+        logger.debug(f"Creating a DataFlow Run with payload {payload}")
         run = DataFlowRun(**payload).create()
         if wait:
             interval = kwargs["interval"] if "interval" in kwargs else 3
