@@ -19,7 +19,7 @@ from ads.common.oci_datascience import DSCNotebookSession, OCIDataScienceMixin
 from ads.common.oci_logging import OCILog
 from ads.common.oci_resource import ResourceNotFoundError
 from ads.jobs.builders.runtimes.artifact import Artifact
-from ads.jobs.builders.infrastructure.base import Infrastructure
+from ads.jobs.builders.infrastructure.base import Infrastructure, RunInstance
 from ads.jobs.builders.infrastructure.utils import get_value
 from ads.jobs.builders.infrastructure.dsc_job_runtime import (
     DataScienceJobRuntimeManager,
@@ -138,13 +138,17 @@ class DSCJob(OCIDataScienceMixin, oci.data_science.models.Job):
                         if infra.job_infrastructure_type
                         else "STANDALONE"
                     )
-                    shape_name = infra.shape_name if infra.shape_name else nb_config.shape
+                    shape_name = (
+                        infra.shape_name if infra.shape_name else nb_config.shape
+                    )
                     block_storage = (
                         infra.block_storage_size_in_gbs
                         if infra.block_storage_size_in_gbs
                         else nb_config.block_storage_size_in_gbs
                     )
-                    subnet_id = infra.subnet_id if infra.subnet_id else nb_config.subnet_id
+                    subnet_id = (
+                        infra.subnet_id if infra.subnet_id else nb_config.subnet_id
+                    )
 
                 self.job_infrastructure_configuration_details = {
                     "jobInfrastructureType": infra_type,
@@ -384,7 +388,9 @@ class DSCJob(OCIDataScienceMixin, oci.data_science.models.Job):
         return instance
 
 
-class DataScienceJobRun(OCIDataScienceMixin, oci.data_science.models.JobRun):
+class DataScienceJobRun(
+    OCIDataScienceMixin, oci.data_science.models.JobRun, RunInstance
+):
     """Represents a Data Science Job run"""
 
     TERMINAL_STATES = [
