@@ -500,11 +500,6 @@ class ScriptRuntimeHandler(CondaRuntimeHandler):
         """
         envs = super()._translate_env(runtime)
         if runtime.entrypoint:
-            # Entrypoint must include the name of the directory
-            # Add the directory to entrypoint if the user did not include it.
-            dir_name = os.path.basename(runtime.source_uri.rstrip("/"))
-            if dir_name != runtime.entrypoint.split("/", 1)[0]:
-                runtime.with_entrypoint(os.path.join(dir_name, runtime.entrypoint))
             envs[self.CONST_ENTRYPOINT] = runtime.entrypoint
         return envs
 
