@@ -3,23 +3,6 @@
 
 # Copyright (c) 2021 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
-
-
-# Standard library
-from typing import Union, List, Optional
-import os
-
-# Third party
-import pandas as pd
-
-# Oracle
-from .common import utils
-from .common.utils import OCIClientManager, State
-import oci
-
-from .model_deployment import ModelDeployment, DEFAULT_WAIT_TIME, DEFAULT_POLL_INTERVAL
-from .model_deployment_properties import ModelDeploymentProperties
-
 """
 APIs to interact with Oracle's Model Deployment service.
 
@@ -45,19 +28,13 @@ Usage:
     >> print(deployment_info.url)
     >> deployer.list_deployments() # Optionally pass in a status
 """
-
-# Standard library
-import os
-import json
 from typing import Union, Dict
 
-# Third party
 import pandas as pd
-
-# Oracle
+import oci.pagination
+from ads.common.auth import default_signer
 from .common import utils
 from .common.utils import OCIClientManager, State
-import oci
 
 from .model_deployment import ModelDeployment, DEFAULT_WAIT_TIME, DEFAULT_POLL_INTERVAL
 from .model_deployment_properties import ModelDeploymentProperties
@@ -68,14 +45,12 @@ class ModelDeployer:
 
     Attributes
     ----------
-    config (dict): deployment configuration
+    config (dict): ADS auth dictionary for OCI authentication.
     ds_client (DataScienceClient): data science client
     ds_composite_client (DataScienceCompositeClient): composite data science client
 
     Methods
     -------
-    load_config(config_file)
-        Load configuration file for deployment.
     deploy(model_deployment_details, **kwargs)
         Deploy the model specified by `model_deployment_details`.
     get_model_deployment(model_deployment_id:str)
@@ -92,30 +67,22 @@ class ModelDeployer:
 
     """
 
-    def __init__(self, config=None):
-        """Initializes ModelDeployer with optional config
+    def __init__(self, config: dict = None):
+        """Initializes model deployer.
 
-        Args:
-            config (dict or str, optional): Configurations,
-                which can be a dictionary or the path of YAML containing the config.
-                If None, default config will be used.
-
-        The following keys can be used in the config:
-        auth: Authentication method, must be either "resource_principal" or "api_key".
-            If auth is not specified:
-                1. api_key will be used if available.
-                2. If api_key is not available, resource_principal will be used.
-        oci_config_file: OCI API key config file location. Defaults to "~/.oci/config"
-        oci_config_profile: OCI API key config profile name. Defaults to "DEFAULT"
-        oci_odsc_service_endpoint: URL of the service endpoint. Defaults to OCI production endpoint.
-            This is for debugging/integration testing purpose.
+        Parameters
+        ----------
+        config : dict, optional
+            ADS auth dictionary for OCI authentication.
+            This can be generated by calling ads.common.auth.api_keys() or ads.common.auth.resource_principal().
+            If this is None, ads.common.default_signer(client_kwargs) will be used.
         """
-        # self.config contains contents of yml file/dict passed in by user
-        self.config = utils.load_config(config)
-        self.ds_client = OCIClientManager.oci_ds_client(self.config)
-        self.ds_composite_client = OCIClientManager.oci_ds_composite_client(
-            self.ds_client
-        )
+        if not config:
+            config = default_signer()
+        self.config = config
+        self.client_manager = OCIClientManager(config)
+        self.ds_client = self.client_manager.ds_client
+        self.ds_composite_client = self.client_manager.ds_composite_client
 
     def deploy(
         self,
@@ -127,23 +94,32 @@ class ModelDeployer:
     ) -> ModelDeployment:
         """Deploys a model.
 
-        Args:
-            properties (ModelDeploymentProperties or dict): properties to deploy the model.
-                properties can be None when kwargs are used for specifying properties.
-            wait_for_completion (bool, optional): Flag set for whether to wait for deployment to complete before
-                proceeding. Defaults to True
-            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 1200). Negative implies infinite wait time.
-            poll_interval (int, optional): Poll interval in seconds (Defaults to 30).
-            kwargs: Keyword arguments for initializing ModelDeploymentProperties
+        Parameters
+        ----------
+        properties : ModelDeploymentProperties or dict
+            properties to deploy the model.
+            properties can be None when kwargs are used for specifying properties.
+        wait_for_completion : bool
+            Flag set for whether to wait for deployment to complete before proceeding.
+            Optional, defaults to True.
+        max_wait_time : int
+            Maximum amount of time to wait in seconds. Optional, defaults to 1200.
+            Negative value implies infinite wait time.
+        poll_interval : int
+            Poll interval in seconds. Optional, defaults to 30.
+        kwargs :
+            Keyword arguments for initializing ModelDeploymentProperties.
+            See ModelDeploymentProperties() for details.
+
+        Returns
+        -------
+        ModelDeployment
+            A ModelDeployment instance.
 
-        Returns:
-            ModelDeployment: ModelDeployment objects that was deployed
         """
         model_deployment = ModelDeployment(
             properties,
             config=self.config,
-            ds_client=self.ds_client,
-            ds_composite_client=self.ds_composite_client,
             **kwargs,
         )
         return model_deployment.deploy(
@@ -161,29 +137,40 @@ class ModelDeployer:
     ) -> ModelDeployment:
         """Deploys a model.
 
-        Args:
-            model_uri (str): uri to model files, can be local or in cloud storage
-            properties (ModelDeploymentProperties or dict): properties to deploy the model.
-                properties can be None when kwargs are used for specifying properties.
-            wait_for_completion (bool, optional): Flag set for whether to wait for deployment to complete before
-                proceeding. Defaults to True
-            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 1200). Negative implies infinite wait time.
-            poll_interval (int, optional): Poll interval in seconds (Defaults to 30).
-            kwargs: Keyword arguments for initializing ModelDeploymentProperties
+        Parameters
+        ----------
+        model_uri : str
+            uri to model files, can be local or in cloud storage
+        properties : ModelDeploymentProperties or dict
+            properties to deploy the model.
+            properties can be None when kwargs are used for specifying properties.
+        wait_for_completion : bool
+            Flag set for whether to wait for deployment to complete before proceeding.
+            Defaults to True
+        max_wait_time : int
+            Maximum amount of time to wait in seconds (Defaults to 1200).
+            Negative implies infinite wait time.
+        poll_interval : int
+            Poll interval in seconds (Defaults to 30).
+        kwargs :
+            Keyword arguments for initializing ModelDeploymentProperties
+
+        Returns
+        -------
+        ModelDeployment
+            A ModelDeployment instance
 
-        Returns:
-            ModelDeployment: ModelDeployment object that was deployed
         """
         if properties:
-            model_id = OCIClientManager._prepare_artifact(
-                model_uri=model_uri, properties=properties, ds_client=self.ds_client
+            model_id = self.client_manager.prepare_artifact(
+                model_uri=model_uri, properties=properties
             )
             properties.model_deployment_configuration_details.model_configuration_details.model_id = (
                 model_id
             )
         else:
-            model_id = OCIClientManager._prepare_artifact(
-                model_uri=model_uri, properties=kwargs, ds_client=self.ds_client
+            model_id = self.client_manager.prepare_artifact(
+                model_uri=model_uri, properties=kwargs
             )
             kwargs["model_id"] = model_id
 
@@ -206,18 +193,28 @@ class ModelDeployer:
     ) -> ModelDeployment:
         """Updates an existing model deployment.
 
-        Args:
-            model_deployment_id (str): Model deployment OCID
-            properties (ModelDeploymentProperties, optional): An instance of ModelDeploymentProperties or
-                dict to initialize the ModelDeploymentProperties. Defaults to None.
-            wait_for_completion (bool, optional): Flag set for whether to wait for deployment to complete before
-                proceeding. Defaults to True
-            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 1200).
-            poll_interval (int, optional): Poll interval in seconds (Defaults to 30).
-            kwargs: Updates can also be specified in keyword arguments.
+        Parameters
+        ----------
+        model_deployment_id : str
+            Model deployment OCID
+        properties : ModelDeploymentProperties
+            An instance of ModelDeploymentProperties or dict to initialize the ModelDeploymentProperties.
+            Defaults to None.
+        wait_for_completion : bool
+            Flag set for whether to wait for deployment to complete before proceeding.
+            Defaults to True
+        max_wait_time : int
+            Maximum amount of time to wait in seconds (Defaults to 1200).
+        poll_interval : int
+            Poll interval in seconds (Defaults to 30).
+        kwargs :
+            Keyword arguments for initializing ModelDeploymentProperties.
 
-        Returns:
-            ModelDeployment: a ModelDeployment object
+            
+        Returns
+        -------
+        ModelDeployment
+            A ModelDeployment instance
 
         """
 
@@ -232,13 +229,18 @@ class ModelDeployer:
         )
 
     def get_model_deployment(self, model_deployment_id: str) -> ModelDeployment:
-        """get_model_deployment returns the ModelDeployment specified by `model_deployment_id`.
+        """Gets a ModelDeployment by OCID.
 
-        Args:
-            model_deployment_id (str): the model deployment ocid
+        Parameters
+        ----------
+        model_deployment_id : str
+            Model deployment OCID
+
+        Returns
+        -------
+        ModelDeployment
+            A ModelDeployment instance
 
-        Returns:
-            [ModelDeployment]: a ModelDeployment object
         """
 
         try:
@@ -248,8 +250,6 @@ class ModelDeployer:
             model_deployment_object = ModelDeployment(
                 oci_model_deployment_object,
                 config=self.config,
-                ds_client=self.ds_client,
-                ds_composite_client=self.ds_composite_client,
             )
             return model_deployment_object
         except Exception as e:
@@ -259,13 +259,19 @@ class ModelDeployer:
             raise e
 
     def get_model_deployment_state(self, model_deployment_id: str) -> State:
-        """get_model_deployment_state returns the state of the current deployment specified by id
+        """Gets the state of a deployment specified by OCID
 
-        Args:
-            model_deployment_id (str): the model deployment ocid
+        Parameters
+        ----------
+        model_deployment_id : str
+            Model deployment OCID
+
+
+        Returns
+        -------
+        str
+            The state of the deployment
 
-        Returns:
-            [str]: current state of the deployment specified by model_deployment_id
         """
 
         model_deployment = self.get_model_deployment(model_deployment_id)
@@ -278,17 +284,24 @@ class ModelDeployer:
         max_wait_time: int = DEFAULT_WAIT_TIME,
         poll_interval: int = DEFAULT_POLL_INTERVAL,
     ) -> ModelDeployment:
-        """delete removes the model deployment specified by the id or Model Deployment Object
+        """Deletes the model deployment specified by OCID.
 
-        Args:
-            model_deployment (str): the model deployment ocid
-            wait_for_completion (bool, optional): Wait for deletion to complete. Defaults to True.
-            max_wait_time (int, optional): Maximum amount of time to wait in seconds (Defaults to 600).
-                Negative implies infinite wait time.
-            poll_interval (int, optional): Poll interval in seconds (Defaults to 60).
+        Parameters
+        ----------
+        model_deployment_id : str
+            Model deployment OCID
+        wait_for_completion : bool
+            Wait for deletion to complete. Defaults to True.
+        max_wait_time : int
+            Maximum amount of time to wait in seconds (Defaults to 600).
+            Negative implies infinite wait time.
+        poll_interval : int
+            Poll interval in seconds (Defaults to 60).
+
+        Returns
+        -------
+            A ModelDeployment instance that was deleted
 
-        Returns:
-            ModelDeployment object that was deleted
         """
         try:
             model_deployment_object = self.get_model_deployment(model_deployment_id)
@@ -304,23 +317,33 @@ class ModelDeployer:
     def list_deployments(self, status=None, compartment_id=None, **kwargs) -> list:
         """Lists the model deployments associated with current compartment and data science client
 
-        Args:
-            status (str, optional): Status of deployment. Defaults to None.
-            compartment_id (str, optional): Target compartment to list deployments from.
-                Defaults to the compartment set in the environment variable "NB_SESSION_COMPARTMENT_OCID".
-                If "NB_SESSION_COMPARTMENT_OCID" is not set, the root compartment ID will be used.
-                An ValueError will be raised if root compartment ID cannot be determined.
-            kwargs: The values are passed to oci.data_science.DataScienceClient.list_model_deployments.
+        Parameters
+        ----------
+        status : str
+            Status of deployment. Defaults to None.
+        compartment_id : str
+            Target compartment to list deployments from.
+            Defaults to the compartment set in the environment variable "NB_SESSION_COMPARTMENT_OCID".
+            If "NB_SESSION_COMPARTMENT_OCID" is not set, the root compartment ID will be used.
+            An ValueError will be raised if root compartment ID cannot be determined.
+        kwargs :
+            The values are passed to oci.data_science.DataScienceClient.list_model_deployments.
+        **kwargs :
+            
 
-        Returns:
-            list: A list of ModelDeployment objects.
+        Returns
+        -------
+        list
+            A list of ModelDeployment objects.
 
-        Raises:
-            ValueError: If compartment_id is not specified and cannot be determined from the environment.
+        Raises
+        ------
+        ValueError
+            If compartment_id is not specified and cannot be determined from the environment.
 
         """
         if not compartment_id:
-            compartment_id = OCIClientManager.default_compartment_id()
+            compartment_id = self.client_manager.default_compartment_id()
         if not compartment_id:
             raise ValueError(
                 "Unable to determine compartment ID from environment. Please specify compartment_id."
@@ -337,24 +360,46 @@ class ModelDeployer:
             self.ds_client.list_model_deployments, compartment_id, **kwargs
         ).data
 
-        return [ModelDeployment(deployment) for deployment in deployments]
+        return [ModelDeployment(deployment, config=self.config) for deployment in deployments]
 
     def show_deployments(
         self,
         status=None,
-        compartment_id=os.environ.get("NB_SESSION_COMPARTMENT_OCID", None),
+        compartment_id=None,
     ) -> pd.DataFrame:
         """Returns the model deployments associated with current compartment and data science client
             as a Dataframe that can be easily visualized
 
-        Args:
-            status ([str], optional): Status of deployment. Defaults to None.
-            compartment_id ([str], optional): Target compartment from which to list deployments.
-                                              Defaults to compartment set in the environment.
+        Parameters
+        ----------
+        status : str
+            Status of deployment. Defaults to None.
+        compartment_id : str
+            Target compartment to list deployments from.
+            Defaults to the compartment set in the environment variable "NB_SESSION_COMPARTMENT_OCID".
+            If "NB_SESSION_COMPARTMENT_OCID" is not set, the root compartment ID will be used.
+            An ValueError will be raised if root compartment ID cannot be determined.
+            
+
+        Returns
+        -------
+        DataFrame
+            pandas Dataframe containing information about the ModelDeployments
+
+        Raises
+        ------
+        ValueError
+            If compartment_id is not specified and cannot be determined from the environment.
+
 
-        Returns:
-            [pd.DataFrame]: Dataframe containing information about the ModelDeployments
         """
+        if not compartment_id:
+            compartment_id = self.client_manager.default_compartment_id()
+        if not compartment_id:
+            raise ValueError(
+                "Unable to determine compartment ID from environment. Please specify compartment_id."
+            )
+
         if type(status) == str or status == None:
             status = State._from_str(status)
         model_deployments = self.ds_client.list_model_deployments(compartment_id).data
