@@ -9,11 +9,6 @@ from typing import Callable
 
 
 class UDF:
-
-    @staticmethod
-    def from_lambda(fn: Callable) -> Callable:
-        return fn
-
     @staticmethod
     def from_regex(regex: str) -> Callable:
         def function(content):
@@ -23,6 +18,5 @@ class UDF:
                     return [match.group(0)]
                 else:
                     return match.groups()
+
         return function
-
-
