@@ -14,7 +14,6 @@ from ads.type_discovery.typed_feature import ConstantTypedFeature
 
 
 class ConstantDetector(AbstractTypeDiscoveryDetector):
-
     def is_constant(self, name, values):
         #
         # if all the values are null we treat this as a const feature
@@ -32,9 +31,11 @@ class ConstantDetector(AbstractTypeDiscoveryDetector):
         return False
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     dd = ConstantDetector()
     print(dd.discover("zipcodes", pd.Series([None, "94065", "94065", "94065", None])))
     print(dd.discover("years", pd.Series([2008, 2008, 2008, 2008, 2008])))
-    df = pd.read_csv("https://artifacthub.oraclecorp.com/dsc-generic/advanced-ds/datasets/flights.csv")
-    print(dd.discover("flights_years", df['Year']))
+    df = pd.read_csv(
+        "https://artifacthub.oraclecorp.com/dsc-generic/advanced-ds/datasets/flights.csv"
+    )
+    print(dd.discover("flights_years", df["Year"]))
